# file_state_manager_py
Python implementation of FileStateManager.

## Usage
It's basically the same as the [Dart version](https://github.com/MasahideMori-SimpleAppli/file_state_manager).

## Support
Basically no support.  
Please file an issue if you have any problems.  
This package is low priority, but may be fixed.

## About version control
The version compatibility of this package is managed in the same way as the Dart version.  
If the version is the same, it will basically behave in the same way.  

The C part will be changed at the time of version upgrade.  
However, versions less than 1.0.0 may change the file structure regardless of the following rules.  
- Changes such as adding variables, structure change that cause problems when reading previous files.
    - C.X.X
- Adding methods, etc.
    - X.C.X
- Minor changes and bug fixes.
    - X.X.C

## License
This software is released under the MIT License, see LICENSE file.

## Copyright notice
The “Dart” name and “Flutter” name are trademarks of Google LLC.  
*The developer of this package is not Google LLC.

## Trademarks
The "Python" name is a trademark of the Python Software Foundation.
*The developer of this package is not affiliated with the Python Software Foundation.